exceptiontools.NegativeDurationError
====================================

.. inheritance-diagram:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NegativeDurationError.NegativeDurationError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
